@@ -39,24 +39,22 @@ PREDEFINED_ENGINES = {'tesseract': {'name': 'Tesseract',
                                 'image_format': 'PPM',
                                 'engine_path': 'ocrad',
                                 'arguments': '-F utf8 $IMAGE',
-                                'old_arguments': ['-F utf8 $IMAGE'],
-                                'version': 0.1},
+                                'old_arguments': [],
+                                'version': 0.0},
                       'gocr': {'name': 'GOCR',
                                'image_format': 'PPM',
                                'engine_path': 'gocr',
                                'arguments': '-f UTF8 $IMAGE',
-                               'old_arguments': ['-f UTF8 $IMAGE'],
-                               'version': 0.1},
+                               'old_arguments': [],
+                               'version': 0.0},
                       'cuneiform': {'name': 'Cuneiform',
                                'image_format': 'BMP',
                                'engine_path': 'cuneiform',
                                'arguments': '-f text -o $FILE $IMAGE >'
                                ' /dev/null 2> /dev/null && cat $FILE'
                                ' && rm $FILE',
-                               'old_arguments': ['-f text -o $FILE $IMAGE >'
-                                      ' /dev/null 2> /dev/null && cat $FILE'
-                                      ' && rm $FILE'],
-                               'version': 0.1},
+                               'old_arguments': [],
+                               'version': 0.0},
                      }
 
 class ConfigurationManager(object):
@@ -132,12 +130,14 @@ class ConfigurationManager(object):
                 continue
             image_format = PREDEFINED_ENGINES[name].get('image_format', 'PPM')
             failure_string = PREDEFINED_ENGINES[name].get('failure_string', '')
+            version = PREDEFINED_ENGINES[name].get('version', 0.0)
             engine = Engine(engine_name,
                             path,
                             arguments,
                             temporary_folder = self.TEMPORARY_FOLDER,
                             image_format = image_format,
-                            failure_string = failure_string)
+                            failure_string = failure_string,
+                            version = version)
             existing_engines.append(engine)
         return existing_engines
 
